@@ -1,8 +1,8 @@
 
-__version__ = "0.6.2"
+__version__ = "0.7"
 __version_vcs_info__ = {
-    'branch': 'hotfix-0.6.2',
-    'revid': '73cec8b',
-    'revno': 438}
+    'branch': 'master',
+    'revid': 'ab4d13b',
+    'revno': 571}
 __version_user_email__ = "skalkoto@grnet.gr"
 __version_user_name__ = "Nikos Skalkotos"
